@@ -43,6 +43,13 @@ class Users(Base):
         """
         return self.client.post("""/api/v4/users/login/sso/code-exchange""", options=options)
 
+    def login_intune(self, options):
+        """Login with Microsoft Intune MAM
+        `Read in Mattermost API docs (users - LoginIntune) <https://developers.mattermost.com/api-documentation/#/operations/LoginIntune>`_
+
+        """
+        return self.client.post("""/oauth/intune""", options=options)
+
     def logout(self):
         """Logout from the Mattermost server
         `Read in Mattermost API docs (users - Logout) <https://developers.mattermost.com/api-documentation/#/operations/Logout>`_
@@ -305,7 +312,7 @@ class Users(Base):
         return self.client.put(f"/api/v4/users/{user_id}/roles", options=options)
 
     def update_user_active(self, user_id, options):
-        """Update user active status
+        """Activate or deactivate a user
 
         user_id: User GUID
         active:
@@ -570,6 +577,18 @@ class Users(Base):
         """
         return self.client.post("""/api/v4/users/login/switch""", options=options)
 
+    def get_login_type(self, options):
+        """Get login authentication type
+
+        id: The user ID (optional, can be used with login_id)
+        login_id: The login ID (email, username, or unique identifier)
+        device_id: The device ID for audit logging purposes
+
+        `Read in Mattermost API docs (users - GetLoginType) <https://developers.mattermost.com/api-documentation/#/operations/GetLoginType>`_
+
+        """
+        return self.client.post("""/api/v4/users/login/type""", options=options)
+
     def create_user_access_token(self, user_id, options):
         """Create a user access token
 
